@@ -117,6 +117,8 @@ struct _AdvancedBacklightPluginPrivate
   GtkWidget *rotation_button[4];
   GtkWidget *brightness_level_label;
   GtkWidget *volume_level_label;
+  GtkWidget *volume_scale;
+  GtkWidget *brightness_scale;
 
   gboolean in_area;
   gboolean on_border;
@@ -137,6 +139,8 @@ struct _AdvancedBacklightPluginPrivate
 
   gint is_n810;
   gint is_770;
+
+  gint notify_id;
   struct timeval last_beep;
   gint brightness_jump;
   gint volume_jump;
@@ -145,6 +149,7 @@ struct _AdvancedBacklightPluginPrivate
 
   gint brightness_level;
   gint volume_level;
+  gboolean mute;
 
   GThread *brightness_thread;
   GAsyncQueue *brightness_queue;
@@ -159,8 +164,8 @@ struct _AdvancedBacklightPluginPrivate
 /* DSME message blob */
 struct dsme_message
 {
-  int type;                     /* ? */
-  int request;                  /* ? */
+  int len;
+  int request;
   void *value;
 };
 
@@ -197,9 +202,9 @@ static void advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin *);
 static void advanced_backlight_plugin_load_settings (AdvancedBacklightPlugin * vsp);
 static void advanced_backlight_plugin_save_settings (AdvancedBacklightPlugin * vsp);
 static void advanced_backlight_plugin_fill_theme_list (AdvancedBacklightPlugin * vsp, GtkWidget * combobox);
-static int get_light_sensor(AdvancedBacklightPlugin * vsp);
+static int get_light_sensor (AdvancedBacklightPlugin * vsp);
 static gboolean is_n810 ();
-static gboolean is_770();
+static gboolean is_770 ();
 
 #ifdef XRANDR
 /* D-Pad mapping */
@@ -256,9 +261,12 @@ advanced_backlight_plugin_get_type (void)
   return item_type;
 }
 #else
-HD_DEFINE_PLUGIN (AdvancedBacklightPlugin, advanced_backlight_plugin, STATUSBAR_TYPE_ITEM)
+HD_DEFINE_PLUGIN (AdvancedBacklightPlugin, advanced_backlight_plugin, STATUSBAR_TYPE_ITEM);
 #endif
-     static void advanced_backlight_plugin_init (AdvancedBacklightPlugin * vsp)
+
+
+static void
+advanced_backlight_plugin_init (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
 
@@ -310,24 +318,35 @@ advanced_backlight_plugin_finalize (GObject * object)
 {
   AdvancedBacklightPlugin *vsp = ADVANCED_BACKLIGHT_PLUGIN (object);
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  int *brightness_value;
+  int *volume_value;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
   advanced_backlight_plugin_save_settings (vsp);
+  gconf_client_notify_remove (priv->gconf_client, priv->notify_id);
 
   priv->all_done = TRUE;
 
-  g_string_free(priv->brightness_level_string, TRUE);
-  g_async_queue_push(priv->brightness_queue, GINT_TO_POINTER(priv->brightness_level));
-  g_thread_join(priv->brightness_thread);
-  g_async_queue_unref(priv->brightness_queue);
-  g_async_queue_unref(priv->brightness_queue);
+  /* Wake up threads */
+  g_string_free (priv->brightness_level_string, TRUE);
+  brightness_value = g_new (int, 1);
+  *brightness_value = priv->brightness_level;
+  g_async_queue_push (priv->brightness_queue, brightness_value);
+
+  g_thread_join (priv->brightness_thread);
+  g_async_queue_unref (priv->brightness_queue);
+  g_async_queue_unref (priv->brightness_queue); /* why twice? */
+
+  volume_value = g_new (int, 1);
+  *volume_value = priv->volume_level;
+  g_async_queue_push (priv->volume_queue, volume_value);
+  g_thread_join (priv->volume_thread);
+  g_async_queue_unref (priv->volume_queue);
+  g_async_queue_unref (priv->volume_queue);
+
+  g_string_free (priv->volume_level_string, TRUE);
 
-  g_string_free(priv->volume_level_string, TRUE);
-  g_async_queue_push(priv->volume_queue, vsp);
-  g_thread_join(priv->volume_thread);
-  g_async_queue_unref(priv->volume_queue);
-  g_async_queue_unref(priv->volume_queue);
 
   /* Destroy local widgets */
   if (priv->menu)
@@ -343,15 +362,16 @@ advanced_backlight_plugin_init_threads (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
 
-  if (! g_thread_supported()) g_thread_init(NULL);
+  if (!g_thread_supported ())
+    g_thread_init (NULL);
 
   priv->all_done = FALSE;
 
-  priv->brightness_queue = g_async_queue_new();
-  priv->brightness_thread = g_thread_create(advanced_backlight_plugin_dsme_update_brightness_thread, vsp, TRUE, NULL);
+  priv->brightness_queue = g_async_queue_new ();
+  priv->brightness_thread = g_thread_create (advanced_backlight_plugin_dsme_update_brightness_thread, vsp, TRUE, NULL);
 
-  priv->volume_queue = g_async_queue_new();
-  priv->volume_thread = g_thread_create(advanced_backlight_plugin_update_volume_thread, vsp, TRUE, NULL);
+  priv->volume_queue = g_async_queue_new ();
+  priv->volume_thread = g_thread_create (advanced_backlight_plugin_update_volume_thread, vsp, TRUE, NULL);
 }
 
 /*
@@ -717,16 +737,20 @@ static void
 brightness_level_changed (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  int *value;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
-  priv->brightness_level = (gint) ((hildon_volumebar_get_level (HILDON_VOLUMEBAR (priv->brightness_slider)) * 127.0) / 100.0) + 1;
-  g_string_printf(priv->brightness_level_string, "%3d", priv->brightness_level - 1);
-  gtk_label_set_text(GTK_LABEL(priv->brightness_level_label), (priv->brightness_level_string)->str);
+  priv->brightness_level = (gint) hildon_volumebar_get_level (HILDON_VOLUMEBAR (priv->brightness_slider));
+
+  g_string_printf (priv->brightness_level_string, "%3d", priv->brightness_level);
+  gtk_label_set_text (GTK_LABEL (priv->brightness_level_label), (priv->brightness_level_string)->str);
   g_debug ("value=%d\n", priv->brightness_level);
   advanced_backlight_plugin_update_icons (vsp);
 
-  g_async_queue_push(priv->brightness_queue, GINT_TO_POINTER(priv->brightness_level));
+  value = g_new (int, 1);
+  *value = priv->brightness_level;
+  g_async_queue_push (priv->brightness_queue, value);
 }
 
 static void
@@ -741,28 +765,35 @@ advanced_backlight_plugin_update_volume_value (AdvancedBacklightPlugin * vsp, gi
 static gpointer
 advanced_backlight_plugin_update_volume_thread (gpointer d)
 {
-  AdvancedBacklightPlugin *vsp = (AdvancedBacklightPlugin *)d;
+  AdvancedBacklightPlugin *vsp = (AdvancedBacklightPlugin *) d;
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
-  gint i=0, j, value, prev_value=-101;
+  gint i = 0, j, value, prev_value = -101;
   gpointer gip;
 
-  g_async_queue_ref(priv->volume_queue);
-  while ((gip = g_async_queue_pop(priv->volume_queue)) && ! priv->all_done) {
-    value = GPOINTER_TO_INT(gip);
-    j = 0;
-    g_async_queue_lock(priv->volume_queue);
-    while ((gip = g_async_queue_try_pop_unlocked(priv->volume_queue)) != NULL) {
-      value = GPOINTER_TO_INT(gip);
-      j++;
+  g_async_queue_ref (priv->volume_queue);
+  while ((gip = g_async_queue_pop (priv->volume_queue)) && !priv->all_done)
+    {
+      value = *(int *) gip;
+      g_free (gip);
+
+      j = 0;
+      g_async_queue_lock (priv->volume_queue);
+      while ((gip = g_async_queue_try_pop_unlocked (priv->volume_queue)) != NULL)
+        {
+          value = *(int *) gip;
+          g_free (gip);
+          j++;
+        }
+      g_async_queue_unlock (priv->volume_queue);
+      if (0)
+        g_debug ("after queue pop j: %d %d\n", j, i);
+      if (prev_value != value)
+        {
+          advanced_backlight_plugin_update_volume_value (vsp, value);
+          prev_value = value;
+        }
     }
-    g_async_queue_unlock(priv->volume_queue);
-    if(0)g_debug("after queue pop j: %d %d\n", j, i);
-    if (prev_value != value) {
-      advanced_backlight_plugin_update_volume_value(vsp, value);
-      prev_value = value;
-    }
-  }
-  return g_thread_self();
+  return g_thread_self ();
 }
 
 /*
@@ -773,19 +804,22 @@ advanced_backlight_plugin_update_volume (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   gint volume;
-  gboolean mute;
+  int *value;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
-  mute = hildon_volumebar_get_mute (HILDON_VOLUMEBAR (priv->volume_slider));
+  priv->mute = hildon_volumebar_get_mute (HILDON_VOLUMEBAR (priv->volume_slider));
   volume = (gint) hildon_volumebar_get_level (HILDON_VOLUMEBAR (priv->volume_slider));
-  if (mute)
+  if (priv->mute)
     volume *= -1;
-  g_string_printf(priv->volume_level_string, "%4d", volume);
-  gtk_label_set_text(GTK_LABEL(priv->volume_level_label), (priv->volume_level_string)->str);
+  g_string_printf (priv->volume_level_string, "%4d", volume);
+  gtk_label_set_text (GTK_LABEL (priv->volume_level_label), (priv->volume_level_string)->str);
   priv->volume_level = volume;
   advanced_backlight_plugin_update_icons (vsp);
-  g_async_queue_push(priv->volume_queue, GINT_TO_POINTER(volume));
+
+  value = g_new (int, 1);
+  *value = volume;
+  g_async_queue_push (priv->volume_queue, value);
 }
 
 static void
@@ -800,6 +834,42 @@ volume_mute_toggled (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
   advanced_backlight_plugin_update_volume (vsp);
 }
 
+static void
+get_volume_scale (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
+{
+  AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  if (GTK_IS_SCALE (widget))
+    {
+      priv->volume_scale = widget;
+    }
+}
+
+static void
+get_brightness_scale (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
+{
+  AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  if (GTK_IS_SCALE (widget))
+    {
+      priv->brightness_scale = widget;
+    }
+}
+
+static void
+gconf_notify_volume (GConfClient * gclient, guint notify_id, GConfEntry * entry, AdvancedBacklightPlugin * vsp)
+{
+  AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  gint volume;
+
+  g_debug ("%s\n", __PRETTY_FUNCTION__);
+
+  volume = gconf_client_get_int (priv->gconf_client, GCONF_MASTER_VOLUME, NULL);
+  priv->mute = (volume < 0);
+  priv->volume_level = (priv->mute ? -1 : 1) * volume;
+  hildon_volumebar_set_mute (HILDON_VOLUMEBAR (priv->volume_slider), priv->mute);
+  hildon_volumebar_set_level (HILDON_VOLUMEBAR (priv->volume_slider), priv->volume_level);
+  advanced_backlight_plugin_update_icons (vsp);
+}
+
 
 /*
  Create the menu widget
@@ -811,6 +881,8 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   GtkWidget *hbox, *vbox, *label, *hbox2, *hbox3;
   PangoFontDescription *small_pfd;
   gint i;
+  GError *err;
+
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
@@ -829,21 +901,28 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   g_signal_connect (G_OBJECT (priv->menu), "map-event", G_CALLBACK (map_event), vsp);
   g_signal_connect (G_OBJECT (priv->menu), "button-release-event", G_CALLBACK (window_event), vsp);
 
+  gconf_client_add_dir (priv->gconf_client, GCONF_OSSO_SOUND_DIR, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+  priv->notify_id = gconf_client_notify_add (priv->gconf_client, GCONF_MASTER_VOLUME,
+                                             (GConfClientNotifyFunc) (gconf_notify_volume), vsp, NULL, &err);
+  if (!priv->notify_id)
+    {
+      g_critical ("Unable to add notification: %s\n", err->message);
+      g_error_free (err);
+    }
+
   /* Create slider for brightness and volume */
   priv->brightness_slider = hildon_hvolumebar_new ();
+  gtk_container_forall (GTK_CONTAINER (priv->brightness_slider), (GtkCallback) get_brightness_scale, vsp);
+  gtk_range_set_increments (GTK_RANGE (priv->brightness_scale), 1, 1);
+  gtk_range_set_range (GTK_RANGE (priv->brightness_scale), 0, 127);
+  gtk_range_set_update_policy (GTK_RANGE (priv->brightness_scale), GTK_UPDATE_DELAYED);
   hildon_volumebar_set_level (HILDON_VOLUMEBAR (priv->brightness_slider), priv->brightness_level);
-
   g_object_set (G_OBJECT (priv->brightness_slider), "has_mute", FALSE, NULL);
   g_signal_connect (G_OBJECT (priv->brightness_slider), "level-changed", G_CALLBACK (brightness_level_changed), vsp);
-  /*
-     priv->brightness_slider = hildon_controlbar_new();
-     hildon_controlbar_set_range(HILDON_CONTROLBAR (priv->brightness_slider), 0, 127);
-     hildon_controlbar_set_value(HILDON_CONTROLBAR(priv->brightness_slider), priv->brightness_level); // Return the controlbar to the last specified value.
-     gtk_range_set_update_policy(GTK_RANGE(priv->brightness_slider), GTK_UPDATE_DELAYED);
-     g_signal_connect(G_OBJECT(priv->brightness_slider), "value-changed", G_CALLBACK(brightness_level_changed), vsp);
-   */
 
   priv->volume_slider = hildon_hvolumebar_new ();
+  gtk_container_forall (GTK_CONTAINER (priv->volume_slider), (GtkCallback) get_volume_scale, vsp);
+  gtk_range_set_increments (GTK_RANGE (priv->volume_scale), 1, 1);
   g_signal_connect (G_OBJECT (priv->volume_slider), "level-changed", G_CALLBACK (volume_level_changed), vsp);
   g_signal_connect (G_OBJECT (priv->volume_slider), "mute-toggled", G_CALLBACK (volume_mute_toggled), vsp);
 
@@ -885,8 +964,8 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   gtk_widget_modify_font (GTK_WIDGET (label), small_pfd);
   gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 
-  priv->brightness_level_string = g_string_new("   ");
-  g_string_printf(priv->brightness_level_string, "%3d", priv->brightness_level - 1);
+  priv->brightness_level_string = g_string_new ("   ");
+  g_string_printf (priv->brightness_level_string, "%3d", priv->brightness_level);
   priv->brightness_level_label = gtk_label_new ((priv->brightness_level_string)->str);
   gtk_misc_set_alignment (GTK_MISC (priv->brightness_level_label), 0.0, 0.5);
   gtk_widget_modify_font (GTK_WIDGET (priv->brightness_level_label), small_pfd);
@@ -903,8 +982,8 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   gtk_widget_modify_font (GTK_WIDGET (label), small_pfd);
   gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
 
-  priv->volume_level_string = g_string_new("   ");
-  g_string_printf(priv->volume_level_string, "%4d", 50);
+  priv->volume_level_string = g_string_new ("   ");
+  g_string_printf (priv->volume_level_string, "%4d", 50);
   priv->volume_level_label = gtk_label_new ((priv->volume_level_string)->str);
   gtk_misc_set_alignment (GTK_MISC (priv->volume_level_label), 0.0, 0.5);
   gtk_widget_modify_font (GTK_WIDGET (priv->volume_level_label), small_pfd);
@@ -1035,10 +1114,11 @@ advanced_backlight_plugin_get_rotation (AdvancedBacklightPlugin * vsp)
   gint rotation;
   XRRScreenConfiguration *rr_screen;
   Rotation current_rotation;
-  g_debug ("%s\n", __PRETTY_FUNCTION__);
   Display *dpy;
   gint screen;
 
+  g_debug ("%s\n", __PRETTY_FUNCTION__);
+
   if (!priv->has_rotation)
     return 0;
 
@@ -1155,7 +1235,7 @@ advanced_backlight_plugin_set_rotation (AdvancedBacklightPlugin * vsp, gint rota
 #endif /* XRANDR */
 
 static void
-advanced_backlight_plugin_dsme_update_brightness_value (AdvancedBacklightPluginPrivate *priv, gint value)
+advanced_backlight_plugin_dsme_update_brightness_value (AdvancedBacklightPluginPrivate * priv, gint value)
 {
   struct dsme_message message;
   gint conn;
@@ -1164,18 +1244,21 @@ advanced_backlight_plugin_dsme_update_brightness_value (AdvancedBacklightPluginP
     return;
 
   value = (priv->brightness_level * 2);
+  if (value == 0)
+    value = 1;
   if (value <= 2 && !priv->allow_zero)
     value = 3;
   if (value > 254)
     value = 254;
 
   conn = dsmesock_connect ();
-  message.type = 0x0c;
+  message.len = 0x0c;
   message.request = 0x289;
   message.value = (void *) value;
   dsmesock_send (conn, &message);
   dsmesock_close (conn);
 }
+
 /*
 static void
 advanced_backlight_plugin_dsme_update_brightness (AdvancedBacklightPlugin * vsp)
@@ -1206,44 +1289,52 @@ advanced_backlight_plugin_dsme_update_brightness (AdvancedBacklightPlugin * vsp)
 static gpointer
 advanced_backlight_plugin_dsme_update_brightness_thread (gpointer d)
 {
-  AdvancedBacklightPlugin *vsp = (AdvancedBacklightPlugin *)d;
+  AdvancedBacklightPlugin *vsp = (AdvancedBacklightPlugin *) d;
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
-  gint i=0, j, value, prev_value=-1;
+  gint i = 0, j, value, prev_value = -1;
   gpointer gip;
 
-  g_async_queue_ref(priv->brightness_queue);
-  while ((gip = g_async_queue_pop(priv->brightness_queue)) && ! priv->all_done) {
-    value = GPOINTER_TO_INT(gip);
-    j = 0;
-    g_async_queue_lock(priv->brightness_queue);
-    while ((gip = g_async_queue_try_pop_unlocked(priv->brightness_queue)) != NULL) {
-      value = GPOINTER_TO_INT(gip);
-      j++;
+  g_async_queue_ref (priv->brightness_queue);
+  while ((gip = g_async_queue_pop (priv->brightness_queue)) && !priv->all_done)
+    {
+      value = *(int *) gip;
+      g_free (gip);
+      j = 0;
+      g_async_queue_lock (priv->brightness_queue);
+      while ((gip = g_async_queue_try_pop_unlocked (priv->brightness_queue)) != NULL)
+        {
+          value = *(int *) gip;
+          g_free (gip);
+          j++;
+        }
+      g_async_queue_unlock (priv->brightness_queue);
+      if (0)
+        g_debug ("after queue pop j: %d %d\n", j, i);
+      if (prev_value != value)
+        {
+          if (!is_770 ())
+            advanced_backlight_plugin_dsme_update_brightness_value (priv, value);
+          else
+            advanced_backlight_plugin_770_update_brightness_value (priv, value);
+          prev_value = value;
+        }
     }
-    g_async_queue_unlock(priv->brightness_queue);
-    if(0)g_debug("after queue pop j: %d %d\n", j, i);
-    if (prev_value != value) {
-      if (!is_770())
-        advanced_backlight_plugin_dsme_update_brightness_value(priv, value);
-      else 
-        advanced_backlight_plugin_770_update_brightness_value(priv, value);
-      prev_value = value;
-    }
-  }
-  return g_thread_self();
+  return g_thread_self ();
 }
 
 static void
-advanced_backlight_plugin_770_update_brightness_value (AdvancedBacklightPluginPrivate *priv, gint value)
+advanced_backlight_plugin_770_update_brightness_value (AdvancedBacklightPluginPrivate * priv, gint value)
 {
-  value = value * 256 + 128; // Math stolen directly from Fanoush's blset script.
+  FILE *myfile;
+  value = value * 254 + 128;    /* Math stolen directly from Fanoush's blset script. was 256 + 128 */
 
-  FILE* myfile = fopen ("/sys/devices/platform/omapfb/panel/backlight_level", "w");
+  myfile = fopen (SYSFS_BRIGHTNESS, "w");
 
-  if (myfile != NULL) {
-    fprintf(myfile, "%d\n", value);
-    fclose(myfile);
-  }
+  if (myfile != NULL)
+    {
+      fprintf (myfile, "%d\n", value);
+      fclose (myfile);
+    }
 }
 
 /*
@@ -1316,6 +1407,7 @@ advanced_backlight_plugin_load_settings (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   GConfValue *conf_value;
+  int *value;
 
   /* Brightness level */
   conf_value = gconf_client_get (priv->gconf_client, GCONF_KEY_BRIGHTNESS, NULL);
@@ -1323,7 +1415,9 @@ advanced_backlight_plugin_load_settings (AdvancedBacklightPlugin * vsp)
     {
       priv->brightness_level = gconf_value_get_int (conf_value);
       /* advanced_backlight_plugin_dsme_update_brightness (vsp); */
-      g_async_queue_push(priv->brightness_queue, GINT_TO_POINTER(priv->brightness_level));
+      value = g_new (int, 1);
+      *value = priv->brightness_level;
+      g_async_queue_push (priv->brightness_queue, value);
       gconf_value_free (conf_value);
     }
   else
@@ -1584,7 +1678,7 @@ advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin * vsp)
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
   volume = priv->volume_level;
-  if (volume < 0 || hildon_volumebar_get_mute (HILDON_VOLUMEBAR (priv->volume_slider)))
+  if (priv->mute)
     volume_icon = NUM_VOLUME_ICONS - 1;
   else
     {
@@ -1604,19 +1698,22 @@ advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin * vsp)
 
 }
 
-static int get_light_sensor(AdvancedBacklightPlugin * vsp) {
-  /*AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);*/
+static int
+get_light_sensor (AdvancedBacklightPlugin * vsp)
+{
+  /*AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp); */
   int value = -1;
-  FILE * fp;
+  FILE *fp;
 
-  fp = fopen("/sys/devices/platform/i2c_omap.2/i2c-0/0-0029/lux","r");
+  fp = fopen ("/sys/devices/platform/i2c_omap.2/i2c-0/0-0029/lux", "r");
 
-  if (fp) {
-    fscanf(fp,"%d",&value);
-    fclose(fp);
-  }
+  if (fp)
+    {
+      fscanf (fp, "%d", &value);
+      fclose (fp);
+    }
 
-  return(value);
+  return (value);
 }
 
 #ifdef TEST_PLUGIN
